import { AbstractChecker } from './checkers/AbstractChecker';
import { RegexChecker } from './checkers/RegexChecker';
import { LFListChecker } from './checkers/LFListChecker';

export interface Card {
	id: number;
	name: string;
	desc: string;
}

export interface CheckerInfo {
	type: string;
	statement?: boolean;
	data: any;
}



export async function loadCheckers() {
	const checkersList = new Map<string, AbstractChecker>();

	// add checkers here
	const regexChecker = new RegexChecker();
	checkersList.set('regex', regexChecker);
	const lflistChecker = new LFListChecker();
	checkersList.set('lflist', lflistChecker);

	for (let checkerName of checkersList.keys()) {
		const checker = checkersList.get(checkerName);
		console.log(`Loading checker ${checkerName}`);
		await checker.initialize();
	}
	return checkersList;
}
