import { AbstractChecker, Card } from "./AbstractChecker";
import { promises as fs } from "fs";

type Records = Map<number, number>;

class LFList {
	name: string;
	records: Records;
	constructor(name: string) {
		this.name = name;
		this.records = new Map();
	}
	addRecord(id: number, num: number) {
		this.records.set(id, num);
	}
	getNum(id: number) {
		if (!this.records.has(id)) {
			return 3;
		}
		return this.records.get(id);
	}
}

export class LFListChecker extends AbstractChecker {
	declare info: any;
	lflists: LFList[];
	pendingLists: LFList[];
	expectedCount: number;
	async initialize() {
		this.lflists = [];
		const content = await fs.readFile('./lflist.conf', "utf-8");
		let currentLFList: LFList;
		for (let _line of content.split('\n')) {
			const line = _line.trim();
			if (line.startsWith('#')) {
				continue;
			}
			let match: RegExpMatchArray;
			match = line.match(/^!(.+)$/);
			if (match) {
				const lflistName = match[1];
				currentLFList = new LFList(lflistName);
				console.log(`Loading LFList ${lflistName}`);
				this.lflists.push(currentLFList);
				continue;
			}
			match = line.match(/^(\d+) (\d).*$/);
			if (match) {
				if (currentLFList) {
					currentLFList.addRecord(parseInt(match[1]), parseInt(match[2]));
				}
				continue;	
			}
		}
	}
	async setInfo(info: any) {
		await super.setInfo(info);
		this.pendingLists = this.lflists.filter(list => list.name.match(info.match));
		this.expectedCount = info.limit;
	}
	check(card: Card) {
		return this.pendingLists.some(list => {
			if (this.expectedCount === -1) {
				return list.getNum(card.id) < 3;
			}
			return list.getNum(card.id) === this.expectedCount;
		});
	}
}
